Function spin_executor::run
source · pub fn run<T>(future: impl Future<Output = T>) -> TExpand description
Run the specified future to completion blocking until it yields a result.
Based on an executor using wasi::io/poll/poll-list,
pub fn run<T>(future: impl Future<Output = T>) -> TRun the specified future to completion blocking until it yields a result.
Based on an executor using wasi::io/poll/poll-list,